Hello!

This repo holds the released v1.2 of the Common Workflow Language standard and the history of its development.

You can render this using https://github.com/common-workflow-language/cwl-website/blob/master/website.sh

You may browse the spec online at https://www.commonwl.org/v1.2
